/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_ksh extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "de \u00c4\u00e4d" },
            { "002", "Affrika" },
            { "003", "Nood-Am\u00e4rrika" },
            { "005", "S\u00f6hd-Am\u00e4rrika" },
            { "009", "Ozejahneje" },
            { "011", "W\u00e4\u00df-Affrika" },
            { "013", "Meddelamm\u00e4rrika" },
            { "014", "O\u00df-Affrika" },
            { "015", "Nood-Affrika" },
            { "017", "Meddel-Affrika" },
            { "018", "S\u00f6hd-Affrika" },
            { "019", "Amm\u00e4rrika" },
            { "021", "der Norde vun Am\u00e4rrika" },
            { "029", "de Karribik" },
            { "030", "O\u00df-Aasije" },
            { "034", "S\u00f6hd-Aasije" },
            { "035", "S\u00f6hd-O\u00df-Aasije" },
            { "039", "S\u00f6hd-Europpa" },
            { "053", "de Rejjohn \u00f6m Austrahlije" },
            { "054", "Mellanehsije" },
            { "057", "de Rejohn vun Mikronehseje" },
            { "061", "Polinehsije" },
            { "142", "Aasije" },
            { "143", "Meddelaasije" },
            { "145", "W\u00e4\u00df-Aasije" },
            { "150", "Europpa" },
            { "151", "O\u00df-Europpa" },
            { "154", "Nood-Europpa" },
            { "155", "W\u00e4\u00df-Europpa" },
            { "419", "Lateinam\u00e4rrika" },
            { "AC", "A\u00dfension" },
            { "AD", "Andorra" },
            { "AE", "Vereinschte Arrabesche Emmirate" },
            { "AF", "Afjaanistahn" },
            { "AG", "Antigwa un Barbuda" },
            { "AI", "Anggwilla" },
            { "AL", "Albaanije" },
            { "AM", "Arrmeenije" },
            { "AO", "Angjoola" },
            { "AQ", "der S\u00f6dpol" },
            { "AR", "Ajjentiinije" },
            { "AS", "Ammerikaanesch Sammoha" },
            { "AT", "\u00d6\u00f6sterisch" },
            { "AU", "Austraalije" },
            { "AW", "Aruba" },
            { "AX", "de Ohland-Enselle" },
            { "AZ", "Asserbaidschahn" },
            { "BA", "Bo\u00dfnije un Herzegovina" },
            { "BB", "de Ensel Barbados" },
            { "BD", "Bangladesch" },
            { "BE", "Bellje" },
            { "BF", "Bukkinna-Faase" },
            { "BG", "Bulljaarije" },
            { "BH", "Bachrain" },
            { "BI", "Burundi" },
            { "BJ", "d\u00e4 Benin" },
            { "BL", "de Zint Batt\u00e4lmi-Enselle" },
            { "BM", "de Bermudas" },
            { "BN", "Brunei" },
            { "BO", "Bolliivije" },
            { "BQ", "de karribbesche Nederl\u00e4ng" },
            { "BR", "Brasilije" },
            { "BS", "de Bahamas" },
            { "BT", "Buttaan" },
            { "BV", "de Buvee-Ensel" },
            { "BW", "Bozwaana" },
            { "BY", "Wie\u00dfru\u00dfland" },
            { "BZ", "Belize" },
            { "CA", "Kanada" },
            { "CC", "de Kokkos-Enselle" },
            { "CD", "d\u00e4 Konggo (Kinschasa)" },
            { "CF", "de Z\u00e4ntraalaffrikaanesche Republik" },
            { "CG", "d\u00e4 Konggo (Brassavill)" },
            { "CH", "de Schweiz" },
            { "CI", "\u00c4lfebeijn-K\u00f6\u00df" },
            { "CK", "de Kuuk-Enselle" },
            { "CL", "Schiile" },
            { "CM", "Kammeruhn" },
            { "CN", "Schiina" },
            { "CO", "Kolumbije" },
            { "CP", "de Klipperton-Ensel" },
            { "CR", "Kostarika" },
            { "CU", "Kuhba" },
            { "CV", "de kapv\u00e4rdesche Enselle" },
            { "CW", "Cura\u00e7ao" },
            { "CX", "de Weihnaachs-Ensel" },
            { "CY", "Z\u00fcppere" },
            { "CZ", "de Tsch\u00e4schei" },
            { "DE", "Do\u00fctschland" },
            { "DG", "de Diego-Garcia-Ensel" },
            { "DJ", "Dschibutti" },
            { "DK", "D\u00e4nemark" },
            { "DM", "Dominnika" },
            { "DO", "de Dommenekaanesche Reppublik" },
            { "DZ", "Alljeerije" },
            { "EA", "Ze\u2019uta un Meliija" },
            { "EC", "\u00c4kwador" },
            { "EE", "\u00c4\u00dfland" },
            { "EG", "\u00c4j\u00fcpte" },
            { "EH", "W\u00e4\u00df-Sahara" },
            { "ER", "\u00c4ritreja" },
            { "ES", "Schpaanije" },
            { "ET", "\u00c4ttijoopije" },
            { "EU", "de Europ\u00e4hjesche Unijon" },
            { "FI", "Finnland" },
            { "FJ", "de Fidschi-Endelle" },
            { "FK", "de Falkland-Enselle" },
            { "FM", "Mikroneesije" },
            { "FO", "de F\u00e4rr\u00f6r-Enselle" },
            { "FR", "Frankrisch" },
            { "GA", "Jabuhn" },
            { "GB", "Jruu\u00dfbrettannije" },
            { "GD", "Jrenahda" },
            { "GE", "Jeorrjije" },
            { "GF", "Franz\u00fc\u00fcsesch Jujaana" },
            { "GG", "J\u00f6\u00f6nsei" },
            { "GH", "Jaana" },
            { "GI", "Jibralltaa" },
            { "GL", "Jr\u00f6hnland" },
            { "GM", "Jambija" },
            { "GN", "Jinneha" },
            { "GP", "Juadelupp" },
            { "GQ", "\u00c4quatorial Jineeja" },
            { "GR", "Jriescheland" },
            { "GS", "S\u00f6d-Jeorjie un de s\u00f6dlijje Botteramms-Enselle" },
            { "GT", "Juwatemahla" },
            { "GU", "Juham" },
            { "GW", "Jinneha_Bi\u00dfau" },
            { "GY", "Jujaana" },
            { "HK", "Hongkong" },
            { "HM", "de Heart Ensel un de McDonald-Enselle" },
            { "HN", "Honduras" },
            { "HR", "Krowazije" },
            { "HT", "Ha\u2019itti" },
            { "HU", "Unjann" },
            { "IC", "de Kannaresche Enselle" },
            { "ID", "Indoneesije" },
            { "IE", "Irrland" },
            { "IL", "I\u00dfra\u00e4l" },
            { "IM", "de Ensel M\u00e4n" },
            { "IN", "Indije" },
            { "IO", "Brettesche Besezunge em indesche Oozejahn" },
            { "IQ", "Irak" },
            { "IR", "Persije" },
            { "IS", "I\u00dfland" },
            { "IT", "Itaalije" },
            { "JE", "J\u00f6\u00f6seh" },
            { "JM", "Jammaika" },
            { "JO", "Jordaanije" },
            { "JP", "Japan" },
            { "KE", "Keenija" },
            { "KG", "Kirrjiisije" },
            { "KH", "Kambodscha" },
            { "KI", "Kiribati" },
            { "KM", "de Kommoore" },
            { "KN", "Zint Kitts un Nevis" },
            { "KP", "Nood-Koreja" },
            { "KR", "S\u00f6d-Koreja" },
            { "KW", "Kuweit" },
            { "KY", "de Kaiman-Enselle" },
            { "KZ", "Kassakstahn" },
            { "LA", "La\u2019os" },
            { "LB", "Lebbannon" },
            { "LC", "de Ensel Zint-Lutscha" },
            { "LI", "Lischteschtein" },
            { "LK", "Sri Lanka" },
            { "LR", "Libeerija" },
            { "LS", "Lesooto" },
            { "LT", "Littaue" },
            { "LU", "Luxembursch" },
            { "LV", "L\u00e4tland" },
            { "LY", "Libbije" },
            { "MA", "Marokko" },
            { "MC", "Monakko" },
            { "MD", "Moldaavije" },
            { "ME", "et Monteneejro" },
            { "MF", "de Zint-M\u00e4\u00e4tes-Ensel" },
            { "MG", "Maddajaska" },
            { "MH", "de Machschall-Enselle" },
            { "ML", "Maali" },
            { "MM", "Birma" },
            { "MN", "Mongjolei" },
            { "MO", "Makau" },
            { "MP", "de n\u00f6\u00f6dlijje Marijanne-Enselle" },
            { "MQ", "Machtinik" },
            { "MR", "Mautitaanije" },
            { "MS", "Mong\u00dferrat" },
            { "MT", "Malta" },
            { "MU", "Maurizijus" },
            { "MV", "Mallediive" },
            { "MW", "Malawi" },
            { "MX", "M\u00e4xiko" },
            { "MY", "Malaisije" },
            { "MZ", "Mosambik" },
            { "NA", "Namiibije" },
            { "NC", "Neuschottland" },
            { "NE", "Nijer" },
            { "NF", "de Noofok-Ensel" },
            { "NG", "Nikaraagua" },
            { "NI", "Nikarahguwa" },
            { "NL", "de Nederl\u00e4ng" },
            { "NO", "Norrweeje" },
            { "NP", "Nepall" },
            { "NR", "Nauru" },
            { "NU", "Niue" },
            { "NZ", "Neuseeland" },
            { "OM", "Oman" },
            { "PA", "Pannama" },
            { "PE", "Perruh" },
            { "PF", "Franz\u00fc\u00fcsesch Pollineesije" },
            { "PG", "Papuwa Neujineeja" },
            { "PH", "Fillipiine" },
            { "PK", "Pakistahn" },
            { "PL", "Pole" },
            { "PM", "Zint Pj\u00e4\u00e4r un Mikelong" },
            { "PN", "de Pitk\u00e4rn-Ensel" },
            { "PR", "Pochtoriko" },
            { "PS", "Pal\u00e4stina" },
            { "PT", "Pochtojall" },
            { "PW", "Pallau" },
            { "PY", "Parraguwai" },
            { "QA", "Kataa" },
            { "QO", "Ozejahnije u\u00dferhallef" },
            { "RE", "Rehunjohn" },
            { "RO", "Rom\u00e4\u00e4nije" },
            { "RS", "S\u00e4rbije" },
            { "RU", "Ru\u00dfland" },
            { "RW", "Ruanda" },
            { "SA", "Saudi Arraabije" },
            { "SB", "de Solomone-Enselle" },
            { "SC", "de Seisch\u00e4lle" },
            { "SD", "Noodsudahn" },
            { "SE", "Schweede" },
            { "SG", "Singjapuur" },
            { "SH", "de Ensel Zint Hellena" },
            { "SI", "\u1e9eloveenije" },
            { "SJ", "de Enselle Svalbard un Jan Mayen" },
            { "SK", "\u1e9elovakei" },
            { "SL", "Sj\u00e4rra Lejone" },
            { "SM", "San-Marino" },
            { "SN", "der Sennejall" },
            { "SO", "Somaalije" },
            { "SR", "S\u00fcrinamm" },
            { "SS", "S\u00f6dsudahn" },
            { "ST", "Zint Tommeh un Printschipe" },
            { "SV", "\u00c4l Slavadohr" },
            { "SX", "Zint Maarten" },
            { "SY", "S\u00fcrije" },
            { "SZ", "\u1e9ewaasiland" },
            { "TA", "Tristan da Cunja" },
            { "TC", "de Enselle Turks un Kaikos" },
            { "TD", "der Tschadd" },
            { "TF", "Franz\u00fc\u00fcsesche S\u00f6dsee-Enselle" },
            { "TG", "Toojo" },
            { "TH", "Tailand" },
            { "TJ", "Tadschikistahn" },
            { "TK", "Tokelau" },
            { "TL", "O\u00df-Timor" },
            { "TM", "Turkmenistahn" },
            { "TN", "Tuneesije" },
            { "TO", "Tongga" },
            { "TR", "de T\u00f6rkei" },
            { "TT", "Trinidad un Tob\u00e4hjo" },
            { "TV", "Tuvalu" },
            { "TW", "Taiwan" },
            { "TZ", "Tansanija" },
            { "UA", "de Ukra\u2019iine" },
            { "UG", "Ujanda" },
            { "UM", "de Vereineschte Schtaate vun Am\u00e4rrika ier u\u00dferhallef jel\u00e4\u00e4je Enselsche" },
            { "US", "de vereineschte Schtaate vun Amm\u00e4rrika" },
            { "UY", "Urrujwai" },
            { "UZ", "U\u00dfbeekistahn" },
            { "VA", "der Vattikahn" },
            { "VC", "Zint Vinz\u00e4nz un de Jrenadines-Enselle" },
            { "VE", "Venezuela" },
            { "VG", "de brettesche Juffer-Enselle" },
            { "VI", "de amm\u00e4rrikahnesche Juffer-Enselle" },
            { "VN", "Vij\u00e4tnamm" },
            { "VU", "Vanuatu" },
            { "WF", "Wallis un Futuna" },
            { "WS", "Sammoha" },
            { "XK", "Kosovo" },
            { "YE", "J\u00e4mme" },
            { "YT", "Majott" },
            { "ZA", "de Republik S\u00f6daffrika" },
            { "ZM", "Sambija" },
            { "ZW", "Simbabwe" },
            { "ZZ", "- J\u00e4hjend onbikannt -" },
            { "aa", "Afahresch" },
            { "ab", "Abchahsesch" },
            { "ae", "Av\u00e4stahnesch" },
            { "af", "Afrikaans" },
            { "ak", "Akahnesch" },
            { "am", "Amhahresch" },
            { "an", "Arrajonehsesch" },
            { "ar", "Arahbesch" },
            { "as", "A\u00dfamehsesch" },
            { "av", "Avahresch" },
            { "ay", "Aimahresch" },
            { "az", "Asserbaidschahnesch" },
            { "ba", "Baschkihresch" },
            { "be", "Wii\u00dfru\u00dfesch" },
            { "bg", "Bulljahresch" },
            { "bi", "Bislahmesch" },
            { "bm", "Bambara" },
            { "bn", "B\u00e4ngjahlesch" },
            { "bo", "Tibehtesch" },
            { "br", "Bettohnesch" },
            { "bs", "Bo\u00dfnesch" },
            { "ca", "Kattalahnesch" },
            { "ce", "Tsch\u00e4tschehnesch" },
            { "ch", "Chamorru" },
            { "co", "Korsesch" },
            { "cs", "Tsch\u00e4schesch" },
            { "cu", "Kersche\u00dflahwesch" },
            { "cv", "Tschowaschesch" },
            { "cy", "Wallihsesch" },
            { "da", "D\u00e4hnesch" },
            { "de", "Deutsch" },
            { "dv", "Divehjesch" },
            { "dz", "Butahnesch" },
            { "ee", "Ewe" },
            { "el", "Jrihschesch" },
            { "en", "\u00c4nglesch" },
            { "eo", "Esperanto" },
            { "es", "Schpahnesch" },
            { "et", "\u00c4\u00dfnesch" },
            { "eu", "Baskesch" },
            { "fa", "P\u00e4rsesch" },
            { "ff", "Fulfulde" },
            { "fi", "Finnesch" },
            { "fj", "Fihdschesch" },
            { "fo", "F\u00e4rr\u00f6hresch" },
            { "fr", "Franz\u00fchsesch" },
            { "fy", "W\u00e4\u00dffrihsesch" },
            { "ga", "Ihresch" },
            { "gl", "Jallihzesch" },
            { "gn", "Juwarahnesch" },
            { "gu", "Gutscharatesch" },
            { "gv", "Mangx" },
            { "ha", "Hau\u00dfa" },
            { "he", "Hebr\u00e4hjesch" },
            { "hi", "Hinndi" },
            { "hr", "Krowatesch" },
            { "ht", "Ha\u2019iihtesch" },
            { "hu", "Unnjarresch" },
            { "hy", "Armehnesch" },
            { "hz", "Herrehro" },
            { "ia", "de Interlingua" },
            { "id", "Indonehsesch" },
            { "ig", "Igbo" },
            { "io", "Ihdo" },
            { "is", "I\u00dfl\u00e4nndesch" },
            { "it", "Etallj\u00e4hnesch" },
            { "iu", "Inuktitut" },
            { "ja", "Japahnesch" },
            { "jv", "Javahnesch" },
            { "ka", "Je\u2019orjesch" },
            { "ki", "Rekohjo" },
            { "kj", "Oschivambo" },
            { "kk", "Kassakkesch" },
            { "kl", "Jr\u00f6hnl\u00e4ndesch" },
            { "km", "Khmer" },
            { "kn", "Kannada" },
            { "ko", "Korrejaanesch" },
            { "kr", "Kanuhresch" },
            { "ks", "Kaschmihresch" },
            { "ku", "Kurrdesch" },
            { "kv", "Kohmesch" },
            { "kw", "Kornesch" },
            { "ky", "Kirjihsesch" },
            { "la", "Lateijnesch" },
            { "lb", "Luxemborjesch" },
            { "lg", "Lugannda" },
            { "li", "Lemburjesch" },
            { "ln", "Lingjalla" },
            { "lo", "Lahootesch" },
            { "lt", "Littouesch" },
            { "lu", "Kiluba" },
            { "lv", "L\u00e4ttesch" },
            { "mg", "Madaja\u00dfkesch" },
            { "mh", "Maschallehsesch" },
            { "mi", "Ma\u2019ohresch" },
            { "mk", "Mazedohnesch" },
            { "ml", "Mallajalam" },
            { "mn", "Mongjohlesch" },
            { "mr", "Marrahtesch" },
            { "ms", "Mallaijesch" },
            { "mt", "Maltehsesch" },
            { "my", "Burmehsesch" },
            { "na", "Nauruhesch" },
            { "nb", "Norrwehjesch Bokm\u00e5l" },
            { "nd", "Nood-Ndebele" },
            { "ne", "Nepallehsesch" },
            { "ng", "Ndongjahnesch" },
            { "nl", "Holl\u00e4ndesch" },
            { "nn", "Neu Norrwehjesch" },
            { "no", "Norrwehjesch" },
            { "nv", "Navvacho" },
            { "ny", "Schi-Schewa" },
            { "or", "Oriija" },
            { "os", "O\u00dfeetesch" },
            { "pa", "Panschaabesch" },
            { "pl", "Pollnesch" },
            { "ps", "Paschtuunesch" },
            { "pt", "Pochtojesesch" },
            { "qu", "K\u00e4ttschowa" },
            { "rm", "R\u00e4toromaanesch" },
            { "rn", "K-Rundesch" },
            { "ro", "Rum\u00e4nesch" },
            { "ru", "Ru\u00df\u00dfesch" },
            { "rw", "Kinja-Ruandesch" },
            { "sa", "Sanskrit" },
            { "sd", "Sinndi" },
            { "se", "Nood-Lappl\u00e4ndesch" },
            { "sg", "Sangjo" },
            { "sh", "S\u00e4rbokowatesch" },
            { "si", "Singjaleesesch" },
            { "sk", "\u1e9elovakesch" },
            { "sl", "\u1e9eloveenesch" },
            { "sm", "Sammohanesch" },
            { "sn", "Schi-Schona" },
            { "so", "Somahlesch" },
            { "sq", "Albahnesch" },
            { "sr", "S\u00e4rbesch" },
            { "ss", "Si-Swatesch" },
            { "st", "S\u00f6d-Sooto" },
            { "su", "Sindanehsesch" },
            { "sv", "Schwehdesch" },
            { "sw", "Suahehlesch" },
            { "ta", "Tamihlesch" },
            { "te", "Telluhju" },
            { "tg", "Tadschihkesch" },
            { "th", "Tail\u00e4ndesch" },
            { "ti", "Tijrenejahnesch" },
            { "tk", "T\u00f6rkmehnesch" },
            { "tl", "Tajalloch" },
            { "tn", "Se-Zwahnesch" },
            { "to", "Tongjahnesch" },
            { "tr", "T\u00f6rkesch" },
            { "ts", "Xi-Zongjahnesch" },
            { "tt", "Tattahresch" },
            { "ty", "Tahihtesch" },
            { "ug", "Uj\u2019juhresch" },
            { "uk", "Ukrainesch" },
            { "ur", "Urdu/Hindi" },
            { "uz", "U\u00dfbehkesch" },
            { "ve", "Wenda" },
            { "vi", "Vij\u00e4tnammehsesch" },
            { "vo", "Volap\u00fck" },
            { "wa", "Walohnesch" },
            { "wo", "Woloff" },
            { "xh", "Isi-Khohsa" },
            { "yi", "Jiddesch" },
            { "yo", "Joruhba" },
            { "zh", "Schinehsesch (Mandarin)" },
            { "zu", "Suhlu" },
            { "ace", "Aschenehsesch" },
            { "ada", "Adangmesch" },
            { "ady", "Adygehjsch" },
            { "aeb", "Tonehsesch Arahbesch" },
            { "afh", "Afrehihlesch" },
            { "agq", "Aghehmesch" },
            { "ain", "Aijnu" },
            { "akk", "Akahdesch" },
            { "ale", "Ale\u2019uhtesch" },
            { "ang", "Ahl \u00c4nglesch" },
            { "anp", "Anjikahnesch" },
            { "arp", "Arrappaho" },
            { "arq", "Aljehresch Arahbesch" },
            { "ary", "Marokahnesch Arahbesch" },
            { "arz", "\u00c4jiptesch Arahbesch" },
            { "asa", "Pare" },
            { "ase", "Am\u00e4rrekahnesche Blendeschprohch" },
            { "ast", "Astuhrejahnesch" },
            { "awa", "Awahdesch" },
            { "bal", "Beluhtschesch" },
            { "ban", "Balinehsesch" },
            { "bar", "Bairesch" },
            { "bas", "Basaa-Schprohche" },
            { "bem", "Bemba" },
            { "bez", "Bena" },
            { "bho", "Bhohdschpuresch" },
            { "bin", "Edo" },
            { "bpy", "Bischnuprejahnesch" },
            { "bra", "Brahjesch" },
            { "brh", "Brahuijesch" },
            { "brx", "Boddo" },
            { "bua", "Burejahtesch" },
            { "bug", "Bujinehsesch" },
            { "byn", "Bilihnesch" },
            { "ceb", "Zebuwahnesch" },
            { "cgg", "Kihja-Schprohch" },
            { "chk", "Trukehsesch" },
            { "chm", "Mahresch" },
            { "cho", "Tschoktoh" },
            { "chr", "Tsch\u00e4rrokeh" },
            { "chy", "Tsch\u00e4j\u00e4nn" },
            { "ckb", "Z\u00e4ntrahl-Kurrdesch" },
            { "cop", "Koptesch" },
            { "csb", "Kaschuhbesch" },
            { "dak", "Dakohtesch" },
            { "dar", "Darjihnesch" },
            { "dav", "Dawedahnesch" },
            { "dgr", "Dohjribesch" },
            { "dje", "Djerma" },
            { "dsb", "Niddersorbesch" },
            { "dua", "Du\u2019ala" },
            { "dum", "Meddelnehderl\u00e4ngsch" },
            { "dyo", "Jola-Fonyisch" },
            { "dzg", "Dassajahnesch" },
            { "ebu", "K\u00eeembu" },
            { "efi", "\u00c4ffiksch" },
            { "egl", "Emilijahnesch" },
            { "egy", "Ahl \u00c4jiptesch" },
            { "eka", "Ekajukesch" },
            { "enm", "Meddel\u00e4nglesch" },
            { "esu", "Z\u00e4ntrahl-Juppik" },
            { "ewo", "Ewonndo" },
            { "fil", "Fillipihnesch" },
            { "fon", "Fohnesch" },
            { "fur", "Frijauhlesch" },
            { "gaa", "Jah" },
            { "gez", "Ji\u2019is-Ahl-\u00c4ttejohpesch" },
            { "gil", "Jillb\u00e4ttehsesch" },
            { "gor", "Jorontalohsch" },
            { "gsw", "Schwitzerd\u00fctsch" },
            { "haw", "Hauajahnesch" },
            { "hil", "Hiligaynon" },
            { "hmn", "Hmong" },
            { "hsb", "Bovversorrbesch" },
            { "hup", "Hupa" },
            { "iba", "Ibahnesch" },
            { "ibb", "Ibibio" },
            { "ilo", "Ilokahnesch" },
            { "inh", "Engjuschesch" },
            { "izh", "Ingjrijahnesch" },
            { "jam", "Jamaikahnesch-\u00c4nglesch" },
            { "jbo", "Lodschbahn" },
            { "jgo", "Njomba" },
            { "jpr", "J\u00fchdesch-P\u00e4rsesch" },
            { "jut", "J\u00fcttesch" },
            { "kab", "Kabyhlesch" },
            { "kam", "Kamba vun Kehnija" },
            { "kbd", "Kabadihnesch" },
            { "kde", "Chimakonde" },
            { "kea", "Kapv\u00e4rdesch" },
            { "kfo", "Koro vun de \u00c4lfebeijnk\u00f6\u00df" },
            { "kha", "Khasi" },
            { "khq", "Kojra Tschihni" },
            { "kkj", "Kako" },
            { "kln", "Kal\u00e4ndjihnesch" },
            { "kmb", "Kimbundu" },
            { "kok", "Kon\u2019kahnesch" },
            { "kpe", "Kp\u00e4le" },
            { "krc", "Karatschaj-Balkahresch-T\u00f6rkesch" },
            { "krl", "Karehlesch" },
            { "kru", "Korochesch" },
            { "ksf", "Bafijahnesch" },
            { "ksh", "K\u00f6lsch" },
            { "kum", "Kumykesch" },
            { "lad", "Ladihnesch" },
            { "lag", "Lango" },
            { "lah", "de Landa-Schprooche" },
            { "lez", "Lesjesch" },
            { "lkt", "Lakota" },
            { "loz", "Silohzi" },
            { "lrc", "Nood-Luhresch" },
            { "lua", "Tschiluba" },
            { "lun", "Schilunnda" },
            { "luo", "Luo" },
            { "luy", "Luhjesch" },
            { "mdf", "Mokschah" },
            { "mni", "Meitei-Manipuhresch" },
            { "mua", "Mundang" },
            { "mul", "-ongerscheidlijje Schprohche-" },
            { "mus", "Krihk" },
            { "mwl", "Mirandehsesch" },
            { "myv", "\u00c4rsjahnesch" },
            { "nap", "Napolletahnesch" },
            { "new", "Newahresch" },
            { "nmg", "Gyele" },
            { "nnh", "Njijembohn" },
            { "nog", "Nojal" },
            { "nso", "Nood-Sohto" },
            { "quc", "K\u2019ische\u2019" },
            { "rof", "Kirombo" },
            { "rup", "Arromahnesch" },
            { "sah", "Jackutesch" },
            { "sba", "Njambaij" },
            { "ses", "Kojraboro Senni" },
            { "shi", "Taschelhittesch" },
            { "smj", "Lule-L\u00e4ppl\u00e4ndesch" },
            { "smn", "Inahri Lappl\u00e4ndesch" },
            { "swb", "Kommohresch" },
            { "syr", "S\u00fchrejakkesch" },
            { "tet", "Tetumsch" },
            { "tig", "Tigre" },
            { "tlh", "Klingjohnesch" },
            { "tpi", "Tok Pisin" },
            { "twq", "Tasawaq" },
            { "tyv", "Tuvinijahnesch" },
            { "tzm", "Tamasicht ussem meddlere Atlas" },
            { "udm", "Udmuchtesch" },
            { "umb", "Umbundesch" },
            { "und", "-onbikannte-Schprooch-" },
            { "wae", "Walserd\u00fctsch" },
            { "wal", "Welahmo" },
            { "war", "Waray-Waray" },
            { "xal", "Kalm\u00fckkesch" },
            { "ybb", "J\u00e4mmbah" },
            { "yue", "Kanton-Schinehsesch" },
            { "zun", "Suh\u00f1i" },
            { "zxx", "kein Schprooch" },
            { "zza", "Sahsajesch" },
            { "Arab", "arraabesche Schreff" },
            { "Armn", "armeenesche Schreff" },
            { "Beng", "b\u00e4ngjaalesche Schreff" },
            { "Bopo", "schineeseche \u00d6mschreff Bopomofo" },
            { "Brai", "Blindeschreff" },
            { "Cyrl", "k\u00fcrrellesche Schreff" },
            { "Deva", "indesche Devanajari-Schreff" },
            { "Ethi", "\u00e4tejoopesche Schreff" },
            { "Geor", "je\u2019orrjesche Schreff" },
            { "Grek", "jriischesche Schreff" },
            { "Gujr", "jujaraatesche Schreff" },
            { "Guru", "indesche Gurmukhi-Schreff" },
            { "Hang", "korrejaanesche Schreff" },
            { "Hani", "en schineesesche Schreff" },
            { "Hans", "eijfacher" },
            { "Hant", "tradizjon\u00e4ll" },
            { "Hebr", "hebr\u00e4\u00e4jesche Schreff" },
            { "Hira", "japaanesche Hiddajaana-Schreff" },
            { "Jpan", "en japaanesche Schreff" },
            { "Kana", "japaanesche Kattakaana-Schreff" },
            { "Khmr", "Khmer-Schreff" },
            { "Knda", "indesche Kannada-Schreff" },
            { "Kore", "korrejaanesche Schreff udder en schineesesche Schreff" },
            { "Laoo", "lahootesche Schreff" },
            { "Latn", "lateinesche Schreff" },
            { "Mlym", "indesche Malajalam-Schreff" },
            { "Mong", "mongjoolesche Schreff" },
            { "Mymr", "birmahnesche Schreff" },
            { "Orya", "indesche Orija-Schreff" },
            { "Sinh", "singjaleesesche Schreff" },
            { "Taml", "tamiilesche Schreff" },
            { "Telu", "indesche Telugu-Schreff" },
            { "Thaa", "malledivesche Taana-Schreff" },
            { "Thai", "tail\u00e4ndesche Schreff" },
            { "Tibt", "tibeetesche Schreff" },
            { "Zsym", "-Zeiche \u00e4vver kein Schreff-" },
            { "Zxxx", "-jaa keij Schreff-" },
            { "Zyyy", "-\u00f6hn\u00df en Schreff-" },
            { "Zzzz", "-onbikannte Schreff-" },
            { "de_AT", "Deutsch u\u00df \u00d6h\u00dfterich" },
            { "de_CH", "Deutsch u\u00df de Schweijz" },
            { "en_AU", "\u00c4nglesch u\u00df Au\u00dftrahlije" },
            { "en_CA", "\u00c4nglesch u\u00df Kanada" },
            { "en_GB", "\u00c4nglesch u\u00df Jruh\u00dfbrettannije" },
            { "en_US", "Am\u00e4rrekahnesch \u00c4nglesch" },
            { "es_ES", "Schpahnesch en Schpahneje" },
            { "es_MX", "Schpahnesch en M\u00e4xikoh" },
            { "fr_CA", "Franz\u00fchsesch u\u00df Kanada" },
            { "fr_CH", "Franz\u00fchsesch u\u00df de Schweijz" },
            { "nl_BE", "Fl\u00e4hmesch" },
            { "pt_BR", "Brasilljaanesch Pochtojesesch" },
            { "pt_PT", "Pochtojesesch u\u00df Pochtojall" },
            { "%%1901", "Schriefwii\u00df vun 1901 aff" },
            { "%%1994", "resijanesch schtandatt Schriefwii\u00df vun 1994" },
            { "%%1996", "Schriefwii\u00df vun 1996 aff" },
            { "ar_001", "Schtandatt Arahbesch" },
            { "es_419", "Schpahnesch u\u00df Latting-Amm\u00e4rrika" },
            { "key.ca", "d\u00e4 Kall\u00e4nder" },
            { "key.co", "de Reijefollsch zom Zotiere" },
            { "key.cu", "de Zoot Jeld" },
            { "key.nu", "de Nummere" },
            { "nds_NL", "Nehdersaksesch en de Nederl\u00e4ng" },
            { "%%BISKE", "zint jorjo\u2019sche uder bila\u2019sche reijanesche Dijal\u00e4k" },
            { "%%BOONT", "boontlingsche Dijal\u00e4k" },
            { "%%KKCOR", "jemeinsam widderbel\u00e4f kornesche Schriefwii\u00df" },
            { "%%LIPAW", "lipovazesch resijanesche Dijal\u00e4k" },
            { "%%NEDIS", "natisonesche Dijal\u00e4k" },
            { "%%NJIVA", "gniva\u2019sche uder njiva\u2019sche reijanesche Dijal\u00e4k" },
            { "%%OSOJS", "oseacco\u2019sche uder osojanesche reijanesche Dijal\u00e4k" },
            { "%%ROZAJ", "resijanesche Dijal\u00e4k" },
            { "%%SOLBA", "stolvizanesche uder solbizanesch reijanesche Dijal\u00e4k" },
            { "%%UCCOR", "eijheijtlesch Schriefwii\u00df" },
            { "az_Arab", "S\u00f6dasserbaidschahnesch" },
            { "zh_Hans", "Schinehsesch (eijfache Schreff)" },
            { "zh_Hant", "Schinehsesch (tradizjon\u00e4lle Schreff)" },
            { "%%FONIPA", "IPA-Loutschreff" },
            { "%%FONUPA", "UPA-Loutschreff" },
            { "%%NDYUKA", "ndyukanesche Dijal\u00e4k" },
            { "%%PAMAKA", "pamakanesche Dijal\u00e4k" },
            { "%%PINYIN", "Pinjin-\u00d6mschreff" },
            { "%%SCOUSE", "scouse Dijal\u00e4k" },
            { "%%TARASK", "Taraskijeviza-Schriefwii\u00df" },
            { "%%UCRCOR", "eijheijtlesch, neu opjelate Schriefwii\u00df" },
            { "%%ALALC97", "de lateinesche \u00d6mschreff ALA-LC vun 1997" },
            { "%%AREVELA", "o\u00df-armeensch" },
            { "%%AREVMDA", "w\u00e4\u00df-armeenesch" },
            { "%%HEPBURN", "De Lateinesche \u00d6mschreff noh Hepburn" },
            { "%%MONOTON", "monnotoonesch" },
            { "%%POLYTON", "poll\u00fctoonesch" },
            { "%%REVISED", "neu opjelate Schriefwii\u00df" },
            { "%%1606NICT", "sp\u00e4\u00e4tmeddelfranz\u00fc\u00fcsesch v\u00f6r 1606" },
            { "%%1694ACAD", "fr\u00f6hneufranz\u00fc\u00fcsesch aff 1694" },
            { "%%1959ACAD", "akademesche Schriefwii\u00df vun 1959" },
            { "%%BAKU1926", "eijheijtlesch t\u00f6rkesch lateijnesch Allfabeet" },
            { "%%HOGNORSK", "Huhnorrweejesch" },
            { "%%SCOTLAND", "schottesche Dijal\u00e4k" },
            { "%%VALENCIA", "valenzijaanesche Dijal\u00e4k" },
            { "%%WADEGILE", "lateijnesche \u00d6mschreff noh Wade-Giles" },
            { "type.ca.roc", "rotschineesesche Kal\u00e4nder" },
            { "type.nu.arab", "araabesche un indesche Zeffere" },
            { "type.nu.armn", "armeenesche Zahle" },
            { "type.nu.beng", "b\u00e4ngjaalesche Zeffere" },
            { "type.nu.deva", "Devanagari-Zeffere" },
            { "type.nu.ethi", "\u00e4tejoopesche Zahle" },
            { "type.nu.geor", "jeorjeesche Zahle" },
            { "type.nu.grek", "jriischesche Zahle" },
            { "type.nu.gujr", "Jujarati-Zeffere" },
            { "type.nu.guru", "Jurmukhi-Zeffere" },
            { "type.nu.hans", "eijfache schineesesche Zahle" },
            { "type.nu.hant", "tradizjon\u00e4lle schineesesche Zahle" },
            { "type.nu.hebr", "hebr\u00e4jesche Zahle" },
            { "type.nu.jpan", "japanesche Zahle" },
            { "type.nu.khmr", "Khmer-Zeffere" },
            { "type.nu.knda", "Kannada-Zeffere" },
            { "type.nu.laoo", "laootesche Zeffere" },
            { "type.nu.latn", "w\u00e4\u00dflejje Zeffere" },
            { "type.nu.mlym", "Malayalam-Zeffere" },
            { "type.nu.mong", "mongjoolesche Zeffere" },
            { "type.nu.mymr", "Myanmar-Zeffere" },
            { "type.nu.orya", "Oriya-Zeffere" },
            { "type.nu.taml", "tradizjon\u00e4lle tamilesche Zahle" },
            { "type.nu.telu", "Teluju-Zeffere" },
            { "type.nu.thai", "thail\u00e4ndesche Zeffere" },
            { "type.nu.tibt", "tibetaanesche Zeffere" },
            { "type.ca.dangi", "Dangikal\u00e4nnder" },
            { "type.co.ducet", "standattm\u00e4h\u00dfesch zotehrt nohm Unicode" },
            { "type.nu.roman", "r\u00f6mesche Zahle" },
            { "type.ca.coptic", "kopttesche Kal\u00e4nder" },
            { "type.ca.hebrew", "j\u00fchdesche Kal\u00e4nnder" },
            { "type.ca.indian", "indesche Nazjonahl-Kal\u00e4nder" },
            { "type.co.pinyin", "zoteert noh de Pinjin \u00d6mschreff vum Schineesesch" },
            { "type.co.search", "S\u00f6hke" },
            { "type.co.stroke", "zoteert noh de Stresche vum tradizjon\u00e4ll schineesesch" },
            { "type.co.unihan", "zoteert noh de Radikaale un Stresche vum Schineesesch" },
            { "type.ca.chinese", "schinehsesche Kal\u00e4nnder" },
            { "type.ca.islamic", "i\u00dflaamesche Kal\u00e4nder" },
            { "type.ca.persian", "p\u00e4rsesche Kal\u00e4nder" },
            { "type.co.big5han", "zoteert nohm tradizjon\u00e4ll schineesesch Big5" },
            { "type.nu.arabext", "u\u00dfjedehnt araabesche un indesche Zeffere" },
            { "type.nu.armnlow", "klein jeschrevve armeenesche Zahle" },
            { "type.nu.greklow", "klein jeschrevve jriischesche Zahle" },
            { "type.nu.hanidec", "schineesesche Zehnerzahle" },
            { "type.nu.hansfin", "eijfache schineesesche Finanzzahle" },
            { "type.nu.hantfin", "tradizjon\u00e4lle schineesesche Finanzzahle" },
            { "type.nu.jpanfin", "japaanesche Finazzahle" },
            { "type.nu.tamldec", "tamiilesche Zeffere" },
            { "type.ca.buddhist", "buddistesche Kal\u00e4nder" },
            { "type.ca.ethiopic", "\u00e4tejohpesche Kal\u00e4nnder" },
            { "type.ca.japanese", "japaanesche Kal\u00e4nder" },
            { "type.co.standard", "Schtandatt" },
            { "type.nu.fullwide", "janz breede Zeffere" },
            { "type.nu.romanlow", "klein jeschrevve r\u00f6mesche Zahle" },
            { "type.ca.gregorian", "jrejorejahnesche Kal\u00e4nnder" },
            { "type.co.gb2312han", "zoteert nohm eijfacher schineesesch GB2312" },
            { "type.co.phonebook", "zoteert wi em Tollefoonbooch" },
            { "type.co.dictionary", "zotehrt wi em W\u00f6\u00f6terbohch" },
            { "type.co.traditional", "tradizjon\u00e4ll zoteert" },
            { "type.ca.islamic-civil", "w\u00e4ltlesche islaamesche Kal\u00e4nder" },
            { "ListCompositionPattern", "{0} u\u00df {1}" },
            { "type.ca.ethiopic-amete-alem", "\u00e4tejoopesche Amete Alem Kal\u00e4nder" },
        };
        return data;
    }
}
